@@ -36,11 +36,16 @@ class FacileToolkit2:
 
     def __init__(self):
         self.ajax_activation = "800ms"
+        self.ajax_timeout = "120s"
 
     @keyword
     def set_ajax_activation(self, timeout):
         self.ajax_activation = timeout
 
+    @keyword
+    def set_ajax_timeout(self, timeout):
+        self.ajax_timeout = timeout
+
     @keyword
     def wait(self, keyword, *keywordargs, retry="15x", retry_interval="1s"):
         """
@@ -204,6 +209,7 @@ class FacileToolkit2:
         """
         self.set_selenium_library()
         try:
+            BuiltIn().run_keyword_and_ignore_error("wait_ajax")
             self.sl.log_location()
             self.sl.wait_until_location_contains(url, timeout)
             self.dom_is_loaded(timeout=timeout)
@@ -354,8 +360,10 @@ class FacileToolkit2:
             raise Error(error_thrown)
 
     @keyword
-    def wait_ajax(self, timeout="60s", wait_active=None):
+    def wait_ajax(self, timeout=None, wait_active=None):
         self.set_selenium_library()
+        if is_noney(timeout):
+            timeout = self.ajax_timeout
         if is_noney(wait_active):
             wait_active = self.ajax_activation
         BuiltIn().run_keyword_and_ignore_error("wait_ajax_activation", wait_active)
@@ -497,6 +505,9 @@ class FacileToolkit2:
         firefox_options.add_argument("--no-sandbox")
         firefox_options.add_argument("--disable-gpu")
         firefox_options.add_argument("--disable-extensions")
+        firefox_options.set_preference("browser.link.open_newwindow.restriction", 0)
+
+        firefox_options.set_preference("browser.link.open_newwindow", 3)
         if headless:
             firefox_options.headless = True
         return firefox_options
@@ -605,11 +616,13 @@ class FacileToolkit2:
     @keyword
     def screenshot_on_failure(self):
         BuiltIn().run_keyword_if_test_failed("capture_page_screenshot", "EMBED")
+        self.sl.log_location()
 
     @keyword
     def teardown_with_screenshot(self):
         self.set_selenium_library()
         BuiltIn().run_keyword_if_test_failed("capture_page_screenshot", "EMBED")
+        self.sl.log_location()
         self.sl.close_all_browsers()
 
     def i_see_elements_label(self, *locators):
